# PROD 20240206_v0.10.5_lst_school_dummy_prod

I need this production for the LST school

```
lstmcpipe_generate_config PathConfigAllSkyFullDL1ab --dec_list dec_2276 --prod_id 20240206_v0.10.5_lst_school_dummy_prod --kwargs source_prod_id=20240131_allsky_v0.10.5_all_dec_base
```

contact: Thomas V.